{*****************************************}
{*     PSKCore.DLL Delphi interface      *}
{*  Adapted from PskCoreImplicit.h by    *}
{*            Immortal1977               *}
{*****************************************}

unit PSKCoreIntf;

interface

Uses
  Windows;

const
  PSKCoredllName = 'PSKCore.dll';

  MSG_DATARDY        = 2024;
  MSG_PSKCHARRDY     = 2025;
  MSG_STATUSCHANGE   = 2026;
  MSG_IMDRDY         = 2027;
  MSG_CLKERROR       = 2028;

Type
  PDataArray = ^TDataArray;
  TDataArray = array[0..1023] of integer;

  PSyncArray = ^TSyncArray;
  TSyncArray = array[0..15] of integer;

  PVectorArray = ^TVectorArray;
  TVectorArray = array[0..15] of integer;

  PDataRawArray = ^TDataRawArray;
  TDataRawArray = array[0..2047] of integer;

  PpLengthTime = ^integer;

//  Initialization/Shutdown Functions
function fnStartSoundCard(h_Wnd: HWND; cardnum, numRXchannels: integer): integer; stdcall;
function fnStartRXTXSoundCard(h_Wnd: HWND; Rxcardnum, TXcardnum, numRXchannels: integer): integer; stdcall;
function fnStartSoundCardEx(h_Wnd: HWND; cardnum, numRXchannels, IOMode: integer): integer; stdcall;
procedure fnStopSoundCard; stdcall;

//  RX Functions
function fnEnableRXChannel(channel, enable: integer): integer; stdcall;
function fnIsRXChannelActive (channel: integer): integer; stdcall;
function fnGetNumActiveRXChannels: integer; stdcall;
procedure fnSetRXFrequency(freq, range, channel: integer); stdcall;
procedure fnSetRXPSKMode(mode, chan: integer); stdcall;
function fnGetRXFrequency(channel: integer): integer; stdcall;
procedure fnSetFFTMode(ave, maxscale, mode: integer); stdcall;
function fnGetFFTData(DataArray: PDataArray; fstart, fend: integer): integer; stdcall;
function fnGetClosestPeak(fstart, fend: integer): integer; stdcall;
procedure fnGetSyncData(SyncArray: PSyncArray; channel: integer); stdcall;
procedure fnGetVectorData(VectorArray: PVectorArray; channel: integer); stdcall;
function fnGetRawData(DataRawArray: PDataRawArray; dstart, dend: integer): integer; stdcall;
procedure fnSetAFCLimit(limit, channel: integer); stdcall;
procedure fnSetSquelchThreshold(thresh, mode, channel: integer); stdcall;
function fnGetSignalLevel(channel: integer): integer; stdcall;
procedure fnRewindInput(channel: byte); stdcall;

//  TX Functions
procedure fnStartTX(mode: integer); stdcall;
procedure fnStopTX; stdcall;
procedure fnAbortTX; stdcall;
procedure fnSetTXFrequency(freq: integer); stdcall;
procedure fnSetCWIDString(IDStrg: PChar); stdcall;
function fnSendTXCharacter(txchar, control: integer): integer; stdcall;
function fnSendTXString(lpszTXStrg: PChar): integer; stdcall;
function fnGetTXCharsRemaining: integer; stdcall;
procedure fnClearTXBuffer; stdcall;
procedure fnSetCWIDSpeed(speed: integer); stdcall;
function fnSetComPort(portnum, mode: integer): integer; stdcall;

//  Miscellaneous Functions
procedure fnSetClockErrorAdjustment(ppm: integer); stdcall;
function fnGetDLLVersion: integer; stdcall;
procedure fnGetErrorString(ErrorStr: PChar); stdcall;
function fnSetInputWavePath(Path: Pchar; pLengthTime: PpLengthTime; Offset: integer):integer; stdcall;
function fnSetOutputWavePath(Path: Pchar; TimeLimit: integer; Append: LongBool):integer; stdcall;

implementation

function fnStartSoundCard; external PSKCoredllName;
function fnStartRXTXSoundCard; external PSKCoredllName;
function fnStartSoundCardEx; external PSKCoredllName;
procedure fnStopSoundCard; external PSKCoredllName;

function fnEnableRXChannel; external PSKCoredllName;
function fnIsRXChannelActive; external PSKCoredllName;
function fnGetNumActiveRXChannels; external PSKCoredllName;
procedure fnSetRXFrequency; external PSKCoredllName;
procedure fnSetRXPSKMode; external PSKCoredllName;
function fnGetRXFrequency; external PSKCoredllName;
procedure fnSetFFTMode; external PSKCoredllName;
function fnGetFFTData; external PSKCoredllName;
function fnGetClosestPeak; external PSKCoredllName;
procedure fnGetSyncData; external PSKCoredllName;
procedure fnGetVectorData; external PSKCoredllName;
function fnGetRawData; external PSKCoredllName;
procedure fnSetAFCLimit; external PSKCoredllName;
procedure fnSetSquelchThreshold; external PSKCoredllName;
function fnGetSignalLevel; external PSKCoredllName;
procedure fnRewindInput; external PSKCoredllName;

procedure fnStartTX; external PSKCoredllName;
procedure fnStopTX; external PSKCoredllName;
procedure fnAbortTX; external PSKCoredllName;
procedure fnSetTXFrequency; external PSKCoredllName;
procedure fnSetCWIDString; external PSKCoredllName;
function fnSendTXCharacter; external PSKCoredllName;
function fnSendTXString; external PSKCoredllName;
function fnGetTXCharsRemaining; external PSKCoredllName;
procedure fnClearTXBuffer; external PSKCoredllName;
procedure fnSetCWIDSpeed; external PSKCoredllName;
function fnSetComPort; external PSKCoredllName;

procedure fnSetClockErrorAdjustment; external PSKCoredllName;
function fnGetDLLVersion; external PSKCoredllName;
procedure fnGetErrorString; external PSKCoredllName;
function fnSetInputWavePath; external PSKCoredllName;
function fnSetOutputWavePath; external PSKCoredllName;

end.
